From 28048cdc2dfa7b5b4e157ce4823bfc9bfaf55489 Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Fri, 10 Aug 2012 05:45:37 -0400
Subject: [PATCH] Fixed: FS#2291 - Postfix & Dovecot : unknown user
---
interface/web/sites/ftp_user_list.php | 37 +++++++++++++++++++++++++++----------
1 files changed, 27 insertions(+), 10 deletions(-)
diff --git a/interface/web/sites/ftp_user_list.php b/interface/web/sites/ftp_user_list.php
index 516739f..250efcf 100644
--- a/interface/web/sites/ftp_user_list.php
+++ b/interface/web/sites/ftp_user_list.php
@@ -41,18 +41,35 @@
* End Form configuration
******************************************/
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
- header("Location: ../index.php");
- exit;
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
+
+$app->load('listform_actions');
+
+
+class list_action extends listform_actions {
+
+ function onShow() {
+ global $app,$conf;
+
+ $app->uses('getconf');
+ $global_config = $app->getconf->get_global_config('sites');
+
+ if($global_config['webftp_url'] != '') {
+ $app->tpl->setVar('webftp_link',1);
+ $app->tpl->setVar('webftp_url',$global_config['webftp_url']);
+ } else {
+ $app->tpl->setVar('webftp_link',0);
+ }
+
+ parent::onShow();
+ }
+
}
-$app->uses('listform_actions');
-
-// Limit the results to alias domains
-//$app->listform_actions->SQLExtWhere = "type = 'subdomain'";
-
-$app->listform_actions->onLoad();
+$list = new list_action;
+$list->SQLOrderBy = 'ORDER BY username';
+$list->onLoad();
?>
\ No newline at end of file
--
Gitblit v1.9.1